@@ -6,10 +6,11 @@ class command(object):
     self._matcher = matcher
 
   def __call__(self, func):
-    # Default the command's name to the function's name.
+    # Default the command's name to an exact match of the function's name.
+    # ^func_name$
     matcher = self._matcher
     if matcher is None:
-      matcher = func.func_name
+      matcher = r'^%s$' % func.func_name
 
     # convert matcher to regular expression
     matcher = re.compile(matcher)
@@ -21,6 +22,21 @@ class command(object):
     wrapped_command._matcher = matcher
     return wrapped_command
 
+class privmsg(object):
+  def __init__(self, matcher=None):
+    self._matcher = matcher
+
+  def __call__(self, func):
+    # convert matcher to regular expression
+    matcher = re.compile(self._matcher)
+
+    @functools.wraps(func)
+    def wrapped_command(*args, **kwargs):
+      return func(*args, **kwargs)
+    wrapped_command._type = "PRIVMSG"
+    wrapped_command._matcher = matcher
+    return wrapped_command
+
 def interval(milliseconds):
   def wrapped(func):
     @functools.wraps(func)
